pm4py.algo.conformance.alignments.petri\_net.utils package
==========================================================

Submodules
----------

pm4py.algo.conformance.alignments.petri\_net.utils.log\_enrichment module
-------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.utils.log_enrichment
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.utils
   :members:
   :undoc-members:
   :show-inheritance:
